# Initialize ------------------------------------------------------------------

require(RColorBrewer)
require(R.matlab)
require(dplyr)
require(ggplot2)
full.result <- readMat('results.mat')
loop.over  <- list(c(10, 25, 50), c(10, 50), c(10, 50, 100))
plot.var  <- c(2, 1, 1)

var.names.margin <- c('FFBSi M10', 'FFBSi M25', 'FFBSi M50', 'MH-IPS N10 M10', 
                      'MH-IPS N50 M10', 'PGAS N10', 'PGAS N50',  'PGAS N100')

var.names <- c('FFBSi-RS M10', 'FFBSi-RS M25', 'FFBSi-RS M50', 'MH-IPS N10 M10', 
                      'MH-IPS N50 M10', 'PGAS N10', 'PGAS N50',  'PGAS N100')
# Margin ------------------------------------------------------------------

res <- list(FFBSiRS = tbl_df(as.data.frame(full.result$full.margin)),
            MHIPS = tbl_df(as.data.frame(full.result$mhips.margin)), 
            PGAS = tbl_df(as.data.frame(full.result$pgas.margin))
)
df <- data.frame()
names.cnt <- 1
for (i in 1:3) {
  all <- rowSums(res[[i]][c(5:11)])
  if (i == 1){
    res[[i]]$all <- all+res[[i]][1]
  } else if (i == 2){
    res[[i]]$all <- all+res[[i]][1]+res[[i]][2]*res[[i]][3]
  } else {
    res[[i]]$all <- all+res[[i]][1]*res[[i]][3]
  }
  names(res[[i]])[12] <- 'mu'
  names(res[[i]])[13] <- 'ste'
  loop.df <- res[[i]]
  for (l in loop.over[[i]]) {
    series.ind <- loop.df[plot.var[i]] == l
    add.df <- cbind(loop.df[series.ind, c(12, 13, 14)],
                    data.frame(Method = rep(var.names.margin[[names.cnt]], sum(series.ind))))
    df <- rbind(df, add.df)
    names.cnt <- names.cnt+1
  }
}

pdf('article/margin.pdf', width = 16, height = 9)
p <- ggplot(df, 
            aes(x = all, y = mu, fill = Method))
p <- p+theme_bw()
p <- p+geom_ribbon(aes(ymin = mu-2*ste, ymax = mu+2*ste), alpha = 0.3)
p <- p+geom_line(aes(colour = Method))
p <- p+scale_x_log10(breaks = c(1e7, 1e8, 1e9, 1e10))
p <- p+scale_y_log10()
p <- p+scale_color_brewer(palette = 'Dark2')
p <- p+scale_fill_brewer(palette = 'Dark2')
p <- p+xlab('Operations') 
p <- p+ggtitle('RMSE for Marginalized Double Integrator')
p <- p+ylab('RMSE')
p <- p+annotation_logticks()
p <- p+theme(legend.title=element_blank())
p
dev.off()

# degenerate --------------------------------------------------------------

res <- list(FFBSiRS = tbl_df(as.data.frame(full.result$rsas.degen)),
            MHIPS = tbl_df(as.data.frame(full.result$mhips.degen)), 
            PGAS = tbl_df(as.data.frame(full.result$pgas.degen))
)
df <- data.frame()
names.cnt <- 1
for (i in 1:3) {
  all <- rowSums(res[[i]][c(5:11)])
  if (i == 1){
    res[[i]]$all <- all+res[[i]][1]
  } else if (i == 2){
    res[[i]]$all <- all+res[[i]][1]+res[[i]][2]*res[[i]][3]
  } else {
    res[[i]]$all <- all+res[[i]][1]*res[[i]][3]
  }
  names(res[[i]])[12] <- 'mu'
  names(res[[i]])[13] <- 'ste'
  loop.df <- res[[i]]
  for (l in loop.over[[i]]) {
    series.ind <- loop.df[plot.var[i]] == l
    add.df <- cbind(loop.df[series.ind, c(12, 13, 14)],
                    data.frame(Method = rep(var.names[[names.cnt]], sum(series.ind))))
    df <- rbind(df, add.df)
    names.cnt <- names.cnt+1
  }
}

pdf('article/degen.pdf', width = 16, height = 9)
p <- ggplot(df, 
            aes(x = all, y = mu, fill = Method))
p <- p+theme_bw()
p <- p+geom_ribbon(aes(ymin = mu-2*ste, ymax = mu+2*ste), alpha = 0.3)
p <- p+geom_line(aes(colour = Method))
p <- p+scale_x_log10(breaks = c(1e7, 1e8, 1e9, 1e10))
p <- p+scale_y_log10()
p <- p+scale_color_brewer(palette = 'Dark2')
p <- p+ggtitle('RMSE for the Double Integrator')
p <- p+scale_fill_brewer(palette = 'Dark2')
p <- p+xlab('Operations') 
p <- p+ylab('RMSE')
p <- p+annotation_logticks()
p <- p+theme(legend.title=element_blank())
p
dev.off()


# Nonlin ------------------------------------------------------------------

res <- list(FFBSiRS = tbl_df(as.data.frame(full.result$rsas.nonlin)),
            MHIPS = tbl_df(as.data.frame(full.result$mhips.nonlin)), 
            PGAS = tbl_df(as.data.frame(full.result$pgas.nonlin))
)
df <- data.frame()
names.cnt <- 1
for (i in 1:3) {
  all <- rowSums(res[[i]][c(5:11)])
  if (i == 1){
    res[[i]]$all <- all+res[[i]][1]
  } else if (i == 2){
    res[[i]]$all <- all+res[[i]][1]+res[[i]][2]*res[[i]][3]
  } else {
    res[[i]]$all <- all+res[[i]][1]*res[[i]][3]
  }
  names(res[[i]])[12] <- 'mu'
  names(res[[i]])[13] <- 'ste'
  loop.df <- res[[i]]
  for (l in loop.over[[i]]) {
    series.ind <- loop.df[plot.var[i]] == l
    add.df <- cbind(loop.df[series.ind, c(12, 13, 14)],
                    data.frame(Method = rep(var.names[[names.cnt]], sum(series.ind))))
    df <- rbind(df, add.df)
    names.cnt <- names.cnt+1
  }
}

pdf('article/nonlin.pdf', width = 16, height = 9)
p <- ggplot(df, 
            aes(x = all, y = mu, fill = Method))
p <- p+theme_bw()
p <- p+geom_ribbon(aes(ymin = mu-2*ste, ymax = mu+2*ste), alpha = 0.3)
p <- p+geom_line(aes(colour = Method))
p <- p+scale_x_log10(breaks = c(1e7, 1e8, 1e9, 1e10))
p <- p+scale_y_log10()
p <- p+scale_color_brewer(palette = 'Dark2')
p <- p+ggtitle('RMSE for the Standard Non Linear Model')
p <- p+scale_fill_brewer(palette = 'Dark2')
p <- p+xlab('Operations') 
p <- p+ylab('RMSE')
p <- p+annotation_logticks()
p <- p+theme(legend.title=element_blank())
p
dev.off()

# Tracking ----------------------------------------------------------------

res <- list(FFBSiRS = tbl_df(as.data.frame(full.result$rsas.track)),
            MHIPS = tbl_df(as.data.frame(full.result$mhips.track)), 
            PGAS = tbl_df(as.data.frame(full.result$pgas.track))
)
df <- data.frame()
names.cnt <- 1
for (i in 1:3) {
  all <- rowSums(res[[i]][c(5:11)])
  if (i == 1){
    res[[i]]$all <- all+res[[i]][1]
  } else if (i == 2){
    res[[i]]$all <- all+res[[i]][1]+res[[i]][2]*res[[i]][3]
  } else {
    res[[i]]$all <- all+res[[i]][1]*res[[i]][3]
  }
  names(res[[i]])[12] <- 'mu'
  names(res[[i]])[13] <- 'ste'
  loop.df <- res[[i]]
  for (l in loop.over[[i]]) {
    series.ind <- loop.df[plot.var[i]] == l
    add.df <- cbind(loop.df[series.ind, c(12, 13, 16)],
                    data.frame(Method = rep(var.names[[names.cnt]], sum(series.ind))))
    df <- rbind(df, add.df)
    names.cnt <- names.cnt+1
  }
}


pdf('article/tracking.pdf', width = 16, height = 9)
p <- ggplot(df, aes(x = all, y = mu, fill = Method))
p <- p+theme_bw()
p <- p+ggtitle('RMSE for the Tracking Model')
p <- p+geom_ribbon(aes(ymin = mu-2*ste, ymax = mu+2*ste), alpha = 0.3)
p <- p+geom_line(aes(colour = Method))
p <- p+scale_x_log10(breaks = c(1e7, 1e8, 1e9, 1e10))
p <- p+scale_y_log10()
p <- p+scale_color_brewer(palette = 'Dark2')
p <- p+scale_fill_brewer(palette = 'Dark2')
p <- p+xlab('Operations') 
p <- p+ylab('RMSE')
p <- p+annotation_logticks()
p <- p+theme(legend.title = element_blank())
p
dev.off()



        